#!/usr/bin/env python

from watchdog.observers.polling import PollingObserver
from fileSystemObserverAgent import FileSystemObserverAgent
from dmFileSystemEventHandler import DmFileSystemEventHandler

class WatchdogFileSystemObserverAgent(FileSystemObserverAgent):

    def __init__(self):
        FileSystemObserverAgent.__init__(self)
        self.observer = PollingObserver()
        self.observedWatchDict = {}

    def startObservingPath(self, dataDirectory, experiment):
        self.logger.debug('Starting observer for %s' % dataDirectory)
        eventHandler = DmFileSystemEventHandler(self.fileSystemObserver, dataDirectory, experiment)
        observedWatch = self.observer.schedule(eventHandler, dataDirectory, recursive=True)
        self.observedWatchDict[dataDirectory] = observedWatch

    def stopObservingPath(self, dataDirectory, experiment):
        observedWatch = self.observedWatchDict.get(dataDirectory)
        if observedWatch:
            self.logger.debug('Stopping observer for %s' % dataDirectory)
            self.observer.unschedule(observedWatch)
            del self.observedWatchDict[dataDirectory]
        else:
            self.logger.debug('Observer for %s is not active' % dataDirectory)

    def start(self):
        self.logger.debug('Starting watchdog observer agent')
        self.observer.start()

    def stop(self):
        self.logger.debug('Stopping watchdog observer agent')
        self.observer.stop()
        self.observer.join()

